@@ -4,7 +4,7 @@ package Lingua::Translit;
 # Copyright (C) 2007-2008 ...
 #   Alex Linke <alinke@lingua-systems.com>
 #   Rona Linke <rlinke@lingua-systems.com>
-# Copyright (C) 2009-2015 Lingua-Systems Software GmbH
+# Copyright (C) 2009-2016 Lingua-Systems Software GmbH
 #
 
 use strict;
@@ -17,10 +17,12 @@ use Encode qw/encode decode/;
 
 use Lingua::Translit::Tables;
 
-our $VERSION = '0.23';
+our $VERSION = '0.25';
 
 =pod
 
+=encoding utf8
+
 =head1 NAME
 
 Lingua::Translit - transliterates text between writing systems
@@ -327,6 +329,12 @@ I<ISO 8859-16 RON>, reversible, Romanian with appropriate diacritics
 
 I<Common ARA>, not reversible, Common Romanization of Arabic
 
+=item Sanskrit
+
+I<IAST Devanagari>, not reversible, IAST Romanization to Devanāgarī
+
+I<Devanagari IAST>, not reversible, Devanāgarī to IAST Romanization
+
 =back
 
 =head1 ADDING NEW TRANSLITERATIONS
@@ -362,7 +370,7 @@ Please report bugs to perl@lingua-systems.com.
 
 L<Lingua::Translit::Tables>, L<Encode>, L<perlunicode>
 
-L<translit(1)>
+C<translit>'s manpage
 
 L<http://www.lingua-systems.com/translit/>
 
@@ -382,6 +390,9 @@ Thanks to Dusan Vuckovic for contributing the "ISO/R 9" transliteration table.
 Thanks to Ștefan Suciu for contributing the "ISO 8859-16 RON" transliteration
 table.
 
+Thanks to Philip Kime for contributing the "IAST Devanagari" and "Devanagari
+IAST" transliteration tables.
+
 =head1 AUTHORS
 
 Alex Linke <alinke@lingua-systems.com>
@@ -392,14 +403,14 @@ Rona Linke <rlinke@lingua-systems.com>
 
 Copyright (C) 2007-2008 Alex Linke and Rona Linke
 
-Copyright (C) 2009-2015 Lingua-Systems Software GmbH
+Copyright (C) 2009-2016 Lingua-Systems Software GmbH
 
-This module is free software. It may be used, redistributed
-and/or modified under the terms of either the GPL v2 or the
-Artistic license.
+
+This module is free software; you can redistribute it and/or modify it under
+the same terms as Perl itself.
 
 =cut
 
 1;
 
-# vim: sts=4 sw=4 ts=4 ai et
+# vim: set ft=perl sts=4 sw=4 ts=4 ai et:
