@@ -4,7 +4,7 @@ package Lingua::Translit::Tables;
 # Copyright (C) 2007-2008 ...
 #   Alex Linke <alinke@lingua-systems.com>
 #   Rona Linke <rlinke@lingua-systems.com>
-# Copyright (C) 2009-2015 Lingua-Systems Software GmbH
+# Copyright (C) 2009-2016 Lingua-Systems Software GmbH
 #
 
 use strict;
@@ -13,12 +13,14 @@ use utf8;
 
 require 5.008;
 
-our $VERSION = '0.10';
+our $VERSION = '0.25';
 
 use Carp;
 
 =pod
 
+=encoding utf8
+
 =head1 NAME
 
 Lingua::Translit::Tables - provides transliteration tables
@@ -153,8 +155,8 @@ sub translit_reverse_supported {
 
 =head2 B<translit_list_supported()>
 
-Prints a list of all supported transliterations to STDOUT, providing the
-following information:
+Prints a list of all supported transliterations to STDOUT (UTF-8 encoded),
+providing the following information:
 
   * Name
   * Reversibility
@@ -165,11 +167,15 @@ The same information is provided in this document as well:
 =cut
 
 sub translit_list_supported {
+    require Encode;
+
     foreach my $table ( sort keys %tables ) {
-        my $t = $tables{$table};
-        print "$t->{name}, ",
-          ( $t->{reverse} eq "false" ? "not " : "" ),
-          "reversible, $t->{desc}\n";
+        printf(
+            "%s, %sreversible, %s\n",
+            Encode::encode( 'utf8', $tables{$table}->{name} ),
+            ( $tables{$table}->{reverse} eq "false" ? 'not ' : '' ),
+            Encode::encode( 'utf8', $tables{$table}->{desc} )
+        );
     }
 }
 
@@ -231,6 +237,12 @@ I<ISO 8859-16 RON>, reversible, Romanian with appropriate diacritics
 
 I<Common ARA>, not reversible, Common Romanization of Arabic
 
+=item Sanskrit
+
+I<IAST Devanagari>, not reversible, IAST Romanization to Devanāgarī
+
+I<Devanagari IAST>, not reversible, Devanāgarī to IAST Romanization
+
 =back
 
 =head1 ADDING NEW TRANSLITERATIONS
@@ -274,6 +286,9 @@ Thanks to Dusan Vuckovic for contributing the "ISO/R 9" transliteration table.
 Thanks to Ștefan Suciu for contributing the "ISO 8859-16 RON" transliteration
 table.
 
+Thanks to Philip Kime for contributing the "IAST Devanagari" and "Devanagari
+IAST" transliteration tables.
+
 =head1 AUTHORS
 
 Alex Linke <alinke@lingua-systems.com>
@@ -284,11 +299,10 @@ Rona Linke <rlinke@lingua-systems.com>
 
 Copyright (C) 2007-2008 Alex Linke and Rona Linke
 
-Copyright (C) 2009-2015 Lingua-Systems Software GmbH
+Copyright (C) 2009-2016 Lingua-Systems Software GmbH
 
-This module is free software. It may be used, redistributed
-and/or modified under the terms of either the GPL v2 or the
-Artistic license.
+This module is free software; you can redistribute it and/or modify it under
+the same terms as Perl itself.
 
 =cut
 
@@ -310,4 +324,4 @@ sub _get_table_id {
 
 1;
 
-# vim: sts=4 sw=4 ts=4 ai et
+# vim: set ft=perl sts=4 sw=4 ts=4 ai et:
